aboutsummaryrefslogtreecommitdiff
path: root/src/cmd/vendor/github.com/google/pprof/internal/plugin
diff options
context:
space:
mode:
authorEmmanuel T Odeke <emmanuel@orijtech.com>2024-11-10 12:31:16 -0800
committerEmmanuel Odeke <emmanuel@orijtech.com>2024-11-12 01:08:33 +0000
commitc96939fbed3d60159dc81ee9ad591de8cfd41168 (patch)
tree992defe75b08ec86ffa2e19ed4d7c3d2dd1dd337 /src/cmd/vendor/github.com/google/pprof/internal/plugin
parentfb9b946adcc8389aafaa43866f3cc26b12411439 (diff)
downloadgo-c96939fbed3d60159dc81ee9ad591de8cfd41168.tar.xz
cmd: update github.com/google/pprof dependencies
Spun out of CL 626397, this change vendors in the latest github.com/google/pprof and that also required updating golang.org/x/sys to v0.27. Change-Id: I72ee514494a9e7c36a8943d78f15bdd0445c5cd5 Reviewed-on: https://go-review.googlesource.com/c/go/+/626995 TryBot-Result: Gopher Robot <gobot@golang.org> Reviewed-by: David Chase <drchase@google.com> Run-TryBot: Emmanuel Odeke <emmanuel@orijtech.com> LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accounts.iam.gserviceaccount.com> Reviewed-by: Ian Lance Taylor <iant@google.com>
Diffstat (limited to 'src/cmd/vendor/github.com/google/pprof/internal/plugin')
-rw-r--r--src/cmd/vendor/github.com/google/pprof/internal/plugin/plugin.go9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/cmd/vendor/github.com/google/pprof/internal/plugin/plugin.go b/src/cmd/vendor/github.com/google/pprof/internal/plugin/plugin.go
index f2ef987185..2692c72276 100644
--- a/src/cmd/vendor/github.com/google/pprof/internal/plugin/plugin.go
+++ b/src/cmd/vendor/github.com/google/pprof/internal/plugin/plugin.go
@@ -159,10 +159,11 @@ type ObjFile interface {
// A Frame describes a location in a single line in a source file.
type Frame struct {
- Func string // name of function
- File string // source file name
- Line int // line in file
- Column int // column in line (if available)
+ Func string // name of function
+ File string // source file name
+ Line int // line in file
+ Column int // column in line (if available)
+ StartLine int // start line of function (if available)
}
// A Sym describes a single symbol in an object file.